@@ -3,7 +3,6 @@
 from __future__ import absolute_import
 import copy
 import xml.etree.ElementTree as ET
-import time
 
 
 from svtplay_dl.output import progress_stream, output, ETA, progressbar
@@ -94,5 +93,6 @@ class DASH(VideoRetriever):
 
         if self.options.output != "-":
             file_d.close()
+            progressbar(bytes_so_far, total_size, "ETA: complete")
             progress_stream.write('\n')
             self.finished = True
